VecMap is a vector-based map implementation which retains the order inserted entries.
Structs
A draining iterator for
VecMap.An owning iterator over the entries of a
VecMap.An owning iterator over the keys of a
VecMap.An owning iterator over the values of a
VecMap.An iterator over the entries of a
VecMap.A mutable iterator over the entries of a
VecMap.An iterator over the keys of a
VecMap.A view into an occupied entry in a
VecMap. It is part of the Entry enum.A view into a vacant entry in a
VecMap. It is part of the Entry enum.An iterator over the values of a
VecMap.A mutable iterator over the values of a
VecMap.A vector-based map implementation which retains the order of inserted entries.
Enums
Entry for an existing key-value pair or a vacant location to insert one.